gf2121 opened a new pull request #438:
URL: https://github.com/apache/lucene/pull/438


   In low cardinality points cases, id blocks will usually store doc ids that 
have the same point value, and `intersect` will get into `addAll` logic. If we 
store ids as bitset when the leafCadinality = 1, and give the IntersectVisitor 
bulk visiting ability, we can speed up addAll because we can just execute the 
'or' logic between the result and the block ids.
   
   I mocked a field that has 10,000,000 docs per value and search it with a 
PointInSetQuery with 1 term, the build scorer time decreased from 71ms to 8ms.


-- 
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

To unsubscribe, e-mail: [email protected]

For queries about this service, please contact Infrastructure at:
[email protected]



---------------------------------------------------------------------
To unsubscribe, e-mail: [email protected]
For additional commands, e-mail: [email protected]

Reply via email to